Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev/imcsmb Fix another case of 7-bit right-justified add...



details:   https://anonhg.NetBSD.org/src/rev/26bbd4517455
branches:  trunk
changeset: 830155:26bbd4517455
user:      pgoyette <pgoyette%NetBSD.org@localhost>
date:      Tue Feb 27 05:55:08 2018 +0000

description:
Fix another case of 7-bit right-justified addressing, without write-bit

diffstat:

 sys/dev/imcsmb/imcsmb.c |  4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diffs (16 lines):

diff -r 6eceb7621cd6 -r 26bbd4517455 sys/dev/imcsmb/imcsmb.c
--- a/sys/dev/imcsmb/imcsmb.c   Tue Feb 27 05:52:10 2018 +0000
+++ b/sys/dev/imcsmb/imcsmb.c   Tue Feb 27 05:55:08 2018 +0000
@@ -407,10 +407,10 @@
         */
        if (stat_val & IMCSMB_STATUS_BUS_ERROR_BIT) {
                /* While it is not documented, empirically, SPD page-change
                 * commands (writes with DTI = 0x60) always complete with the
                 * error bit set. So, ignore it in those cases.
                 */
-               if ((addr & 0xf0) != 0x60) {
+               if ((addr & 0x78) != 0x30) {
                        rc = ENODEV;
                        goto out;
                }
@@ -407,10 +407,10 @@
        if (stat_val & IMCSMB_STATUS_BUS_ERROR_BIT) {
                /* While it is not documented, empirically, SPD page-change
-                * commands (writes with DTI = 0x60) always complete with the
+                * commands (writes with DTI = 0x30) always complete with the
                 * error bit set. So, ignore it in those cases.
                 */



Home | Main Index | Thread Index | Old Index